@@ -9,7 +9,7 @@ import sys
 from os.path import isabs
 from pathlib import Path
 from types import ModuleType
-from typing import Any, Dict, Optional
+from typing import Any, Optional
 
 from pelican.log import LimitFilter
 
@@ -24,7 +24,7 @@ def load_source(name: str, path: str) -> ModuleType:
 
 logger = logging.getLogger(__name__)
 
-Settings = Dict[str, Any]
+Settings = dict[str, Any]
 
 DEFAULT_THEME = os.path.join(
     os.path.dirname(os.path.abspath(__file__)), "themes", "notmyidea"
@@ -149,6 +149,7 @@ DEFAULT_CONFIG = {
     "ARTICLE_PERMALINK_STRUCTURE": "",
     "TYPOGRIFY": False,
     "TYPOGRIFY_IGNORE_TAGS": [],
+    "TYPOGRIFY_OMIT_FILTERS": [],
     "TYPOGRIFY_DASHES": "default",
     "SUMMARY_END_SUFFIX": "…",
     "SUMMARY_MAX_LENGTH": 50,
@@ -157,7 +158,7 @@ DEFAULT_CONFIG = {
     "PYGMENTS_RST_OPTIONS": {},
     "TEMPLATE_PAGES": {},
     "TEMPLATE_EXTENSIONS": [".html"],
-    "IGNORE_FILES": [".*"],
+    "IGNORE_FILES": ["**/.*"],
     "SLUG_REGEX_SUBSTITUTIONS": [
         (r"[^\w\s-]", ""),  # remove non-alphabetical/whitespace/'-' chars
         (r"(?u)\A\s*", ""),  # strip leading whitespace
@@ -613,7 +614,7 @@ def configure_settings(settings: Settings) -> Settings:
     ]:
         if key in settings and not isinstance(settings[key], types):
             value = settings.pop(key)
-            logger.warn(
+            logger.warning(
                 "Detected misconfigured %s (%s), falling back to the default (%s)",
                 key,
                 value,
